
#include "../openal/alInclude.h"
#include "../alure/AL/alure.h"
#include <stdio.h>

#ifdef _WIN32
#include <windows.h>
#else
#include <unistd.h>
#define Sleep usleep
#endif

enum MusicState {
   MusicPlaying,
   MusicStopped,
   MusicPaused
};

enum MusicInfoType {
   MusicTypeMenu = 0,
   MusicTypeGame,
   MaxMusicTypes,
};

struct MusicInfo
{
   MusicInfoType type;
   MusicState state;
   ALuint source;
   alureStream* stream;
} musicInfos[8];


typedef int S32;

static const S32 NumMusicStreamBuffers = 3;
static const S32 MusicChunkSize = 250000;
static const S32 NumVoiceChatBuffers = 32;
static const S32 NumSamples = 16;

void menu_music_end_callback(void* userdata, ALuint source)
{
   printf("Done playing music\n");
}

void playMenuMusic(const char *file)
{
   musicInfos[MusicTypeMenu].state = MusicPlaying;

   musicInfos[MusicTypeMenu].stream = alureCreateStreamFromFile(file, MusicChunkSize, 0, NULL);

   if(!musicInfos[MusicTypeMenu].stream)
      printf("Failed to create music stream for: %s\n", file);

   // Loop forever (parameter -1)
   if(!alurePlaySourceStream(musicInfos[MusicTypeMenu].source, musicInfos[MusicTypeMenu].stream, NumMusicStreamBuffers, -1, menu_music_end_callback, NULL))
      printf("Failed to play music file: %s\n", file);
}



int main(int argc, char **argv)
{
   printf("starting\n");
   // Initialize the sound device
   if(!alureInitDevice(NULL, NULL))
   {
      printf("Failed to open OpenAL device: %s\n", alureGetErrorString());
      return 0;
   }

   printf("done with alureInitDevice\n");

   printf("playMenuMusic\n");
   playMenuMusic("music/menu.ogg");

   printf("Music should now be playing\n");
   Sleep(10000);

   printf("Exited\n");

   return 0;
}

